@@ -334,7 +334,7 @@ horizon.datatables.confirm = function(action) {
     modal.css('z-index', child_backdrop.css('z-index')+10);
   }
 
-  modal.find('.' + confirmCssClass).click(function () {
+  modal.find('.' + confirmCssClass).on('click', function () {
     var $form = $action.closest('form');
     var el = document.createElement("input");
     el.type = 'hidden';
@@ -342,7 +342,7 @@ horizon.datatables.confirm = function(action) {
     el.value = $action.attr('value');
     $form
       .append(el)
-      .submit();
+      .trigger('submit');
 
     modal.modal('hide');
     horizon.modals.modal_spinner(gettext("Working"));
@@ -609,7 +609,7 @@ horizon.datatables.update_header_checkbox = function(table) {
     $multi_select_checkbox.prop('checked', false);
     $multi_select_checkbox.attr('disabled', true);
   } else {
-    $multi_select_checkbox.removeAttr('disabled');
+    $multi_select_checkbox.prop('disabled', false);
     var not_checked = $checkboxes.not(':checked').length;
     $multi_select_checkbox.prop('checked', not_checked == 0);
   }
