@@ -13,7 +13,7 @@
 #    under the License.
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
@@ -28,7 +28,6 @@ from openstack_dashboard.dashboards.project.networks.ports \
     import tabs as project_tabs
 from openstack_dashboard.dashboards.project.networks.ports \
     import workflows as project_workflows
-from openstack_dashboard.utils import futurist_utils
 
 
 STATE_DICT = dict(project_tables.DISPLAY_CHOICES)
@@ -69,8 +68,8 @@ class DetailView(tabs.TabbedTableView):
 
         try:
             port = api.neutron.port_get(self.request, port_id)
-            port.admin_state_label = STATE_DICT.get(port.admin_state,
-                                                    port.admin_state)
+            port.admin_state_label = STATE_DICT.get(port.is_admin_state_up,
+                                                    port.is_admin_state_up)
             port.status_label = STATUS_DICT.get(port.status,
                                                 port.status)
             if port.get('binding__vnic_type'):
@@ -90,7 +89,7 @@ class DetailView(tabs.TabbedTableView):
         return port
 
     def get_context_data(self, **kwargs):
-        context = super(DetailView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         port = self.get_data()
         network_url = "horizon:project:networks:detail"
         subnet_url = "horizon:project:networks:subnets:detail"
@@ -106,24 +105,7 @@ class DetailView(tabs.TabbedTableView):
 
             return network
 
-        @memoized.memoized_method
-        def get_security_groups(sg_ids):
-            # Avoid extra API calls if no security group is associated.
-            if not sg_ids:
-                return []
-            try:
-                security_groups = api.neutron.security_group_list(self.request,
-                                                                  id=sg_ids)
-            except Exception:
-                security_groups = []
-                msg = _("Unable to retrieve security groups for the port.")
-                exceptions.handle(self.request, msg)
-            return security_groups
-
-        results = futurist_utils.call_functions_parallel(
-            (get_network, [port.network_id]),
-            (get_security_groups, [tuple(port.security_groups)]))
-        network, port.security_groups = results
+        network = get_network(port.network_id)
 
         port.network_name = network.get('name')
         port.network_url = reverse(network_url, args=[port.network_id])
@@ -173,7 +155,7 @@ class UpdateView(workflows.WorkflowView):
                    'network_id': port['network_id'],
                    'tenant_id': port['tenant_id'],
                    'name': port['name'],
-                   'admin_state': port['admin_state_up'],
+                   'admin_state': port['is_admin_state_up'],
                    'mac_address': port['mac_address'],
                    "target_tenant_id": self.request.user.project_id}
         if port.get('binding__vnic_type'):
